@@ -195,7 +195,7 @@ public class VCalendar extends VObject {
         }
 
         if (!fromServer) {
-            fixTimezone();
+            fixTimezoneToServer();
         }
 
         // iterate over vObjects
@@ -220,6 +220,11 @@ public class VCalendar extends VObject {
                     }
                     String cdoBusyStatus = vObject.getPropertyValue("X-MICROSOFT-CDO-BUSYSTATUS");
                     if (cdoBusyStatus != null) {
+                        // we set status only if it's tentative
+                        if ("TENTATIVE".equals(cdoBusyStatus)) {
+                            vObject.setPropertyValue("STATUS", "TENTATIVE");
+                        }
+                        // in all cases, we set the transparency (also called "show time as" in UI)
                         vObject.setPropertyValue("TRANSP",
                                 !"FREE".equals(cdoBusyStatus) ? "OPAQUE" : "TRANSPARENT");
                     }
@@ -307,7 +312,7 @@ public class VCalendar extends VObject {
 
     }
 
-    private void fixTimezone() {
+    private void fixTimezoneToServer() {
         if (vTimezone != null && vTimezone.vObjects != null && vTimezone.vObjects.size() > 2) {
             VObject standard = null;
             VObject daylight = null;
@@ -331,7 +336,7 @@ public class VCalendar extends VObject {
         }
         // fix 3569922: quick workaround for broken Israeli Timezone issue
         if (vTimezone != null && vTimezone.vObjects != null) {
-            for (VObject vObject:vTimezone.vObjects) {
+            for (VObject vObject : vTimezone.vObjects) {
                 VProperty rrule = vObject.getProperty("RRULE");
                 if (rrule != null && rrule.getValues().size() == 3 && "BYDAY=-2SU".equals(rrule.getValues().get(1))) {
                     rrule.getValues().set(1, "BYDAY=4SU");
@@ -344,6 +349,47 @@ public class VCalendar extends VObject {
                 }
             }
         }
+        // convert TZID to Exchange time zone id
+        ResourceBundle tzBundle = ResourceBundle.getBundle("exchtimezones");
+        ResourceBundle tzidsBundle = ResourceBundle.getBundle("stdtimezones");
+        for (VObject vObject : vObjects) {
+            if (vObject.isVTimezone()) {
+                String tzid = vObject.getPropertyValue("TZID");
+                // check if tzid is avalid Exchange timezone id
+                if (!tzidsBundle.containsKey(tzid)) {
+                    String exchangeTzid = null;
+                    // try to convert standard timezone id to Exchange timezone id
+                    if (tzBundle.containsKey(tzid)) {
+                        exchangeTzid = tzBundle.getString(tzid);
+                    } else {
+                        // failover, map to a close timezone
+                        for (VObject tzDefinition : vObject.vObjects) {
+                            if ("STANDARD".equals(tzDefinition.type)) {
+                                String tzOffset = tzDefinition.getPropertyValue("TZOFFSETTO");
+                                exchangeTzid = ResourceBundle.getBundle("tzoffsettimezones").getString(tzOffset);
+                            }
+                        }
+                    }
+                    if (exchangeTzid != null) {
+                        vObject.setPropertyValue("TZID", exchangeTzid);
+                        // also replace TZID in properties
+                        updateTzid(tzid, exchangeTzid);
+                    }
+                }
+            }
+        }
+    }
+
+    protected void updateTzid(String tzid, String newTzid) {
+        for (VObject vObject : vObjects) {
+            if (vObject.isVEvent()) {
+                for (VProperty vProperty : vObject.properties) {
+                    if (tzid.equalsIgnoreCase(vProperty.getParamValue("TZID"))) {
+                        vProperty.setParam("TZID", newTzid);
+                    }
+                }
+            }
+        }
     }
 
     private void fixTzid(VProperty property) {
@@ -606,8 +652,8 @@ public class VCalendar extends VObject {
         if (vObjects != null) {
             for (VObject vObject : vObjects) {
                 if ("VEVENT".equals(vObject.type)) {
-                    if (vObject.vObjects != null) {
-                        return true;
+                    if (vObject.vObjects != null && !vObject.vObjects.isEmpty()) {
+                        return vObject.vObjects.get(0).isVAlarm();
                     }
                 }
             }
@@ -615,6 +661,37 @@ public class VCalendar extends VObject {
         return false;
     }
 
+    public String getReminderMinutesBeforeStart() {
+        String result = "0";
+        if (vObjects != null) {
+            for (VObject vObject : vObjects) {
+                if (vObject.vObjects != null && !vObject.vObjects.isEmpty() &&
+                        vObject.vObjects.get(0).isVAlarm()) {
+                    String trigger = vObject.vObjects.get(0).getPropertyValue("TRIGGER");
+                    if (trigger != null) {
+                        if (trigger.startsWith("-PT") && trigger.endsWith("M")) {
+                            result = trigger.substring(3, trigger.length() - 1);
+                        } else if (trigger.startsWith("-PT") && trigger.endsWith("H")) {
+                            result = trigger.substring(3, trigger.length() - 1);
+                            // convert to minutes
+                            result = String.valueOf(Integer.parseInt(result) * 60);
+                        } else if (trigger.startsWith("-P") && trigger.endsWith("D")) {
+                            result = trigger.substring(2, trigger.length() - 1);
+                            // convert to minutes
+                            result = String.valueOf(Integer.parseInt(result) * 60 * 24);
+                        } else if (trigger.startsWith("-P") && trigger.endsWith("W")) {
+                            result = trigger.substring(2, trigger.length() - 1);
+                            // convert to minutes
+                            result = String.valueOf(Integer.parseInt(result) * 60 * 24 * 7);
+                        }
+                    }
+                }
+            }
+        }
+        return result;
+    }
+
+
     /**
      * Check if this VCalendar is a meeting.
      *
@@ -728,7 +805,7 @@ public class VCalendar extends VObject {
         return recipients;
     }
 
-    protected String getAttendeeStatus() {
+    public String getAttendeeStatus() {
         String status = null;
         List<VProperty> attendeeProperties = getFirstVeventProperties("ATTENDEE");
         if (attendeeProperties != null) {
@@ -746,6 +823,7 @@ public class VCalendar extends VObject {
 
     /**
      * Get first VEvent
+     *
      * @return first VEvent
      */
     public VObject getFirstVevent() {
@@ -771,4 +849,51 @@ public class VCalendar extends VObject {
         }
         return results;
     }
+
+    public TimeZone getStandardTimezoneId(String tzid) {
+        String convertedTzid = null;
+        // convert Exchange TZID to standard timezone
+        try {
+            convertedTzid = ResourceBundle.getBundle("timezones").getString(tzid);
+        } catch (MissingResourceException e) {
+            // failover: detect timezone from offset
+            VObject vTimezone = getVTimezone();
+            for (VObject tzDefinition : vTimezone.vObjects) {
+                if ("STANDARD".equals(tzDefinition.type)) {
+                    String tzOffset = tzDefinition.getPropertyValue("TZOFFSETTO");
+                    convertedTzid = ResourceBundle.getBundle("tzoffsettimezones").getString(tzOffset);
+                }
+            }
+            convertedTzid = ResourceBundle.getBundle("timezones").getString(tzid);
+        }
+        return TimeZone.getTimeZone(convertedTzid);
+
+    }
+
+    public String convertCalendarDateToExchangeZulu(String vcalendarDateValue, String tzid) throws IOException {
+        String zuluDateValue = null;
+        TimeZone timeZone = null;
+        if (tzid == null) {
+            timeZone = ExchangeSession.GMT_TIMEZONE;
+        } else {
+            timeZone = getStandardTimezoneId(tzid);
+        }
+        if (vcalendarDateValue != null) {
+            try {
+                SimpleDateFormat dateParser;
+                if (vcalendarDateValue.length() == 8) {
+                    dateParser = new SimpleDateFormat("yyyyMMdd", Locale.ENGLISH);
+                } else {
+                    dateParser = new SimpleDateFormat("yyyyMMdd'T'HHmmss", Locale.ENGLISH);
+                }
+                dateParser.setTimeZone(timeZone);
+                SimpleDateFormat dateFormatter = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'", Locale.ENGLISH);
+                dateFormatter.setTimeZone(ExchangeSession.GMT_TIMEZONE);
+                zuluDateValue = dateFormatter.format(dateParser.parse(vcalendarDateValue));
+            } catch (ParseException e) {
+                throw new IOException("Invalid date " + vcalendarDateValue + " with tzid " + tzid);
+            }
+        }
+        return zuluDateValue;
+    }
 }
