@@ -56,6 +56,8 @@ public final class Field {
         FIELD_MAP.put("dtstart", new UnindexedFieldURI("calendar:Start"));
         FIELD_MAP.put("dtend", new UnindexedFieldURI("calendar:End"));
 
+        FIELD_MAP.put("originalstart", new UnindexedFieldURI("calendar:OriginalStart"));
+
         FIELD_MAP.put("mimeContent", new UnindexedFieldURI("item:MimeContent"));
 
         // use PR_RECORD_KEY as unique key
@@ -200,6 +202,9 @@ public final class Field {
         FIELD_MAP.put("private", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.Common, 0x8506, ExtendedFieldURI.PropertyType.Boolean));
         FIELD_MAP.put("sensitivity", new ExtendedFieldURI(0x0036, ExtendedFieldURI.PropertyType.Integer));
 
+        // TODO: merge with sensitivity ?
+        FIELD_MAP.put("itemsensitivity", new UnindexedFieldURI("item:Sensitivity"));
+
         FIELD_MAP.put("haspicture", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.Address, 0x8015, ExtendedFieldURI.PropertyType.Boolean));
 
         FIELD_MAP.put("fburl", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.Address, 0x80D8, ExtendedFieldURI.PropertyType.String));
@@ -208,7 +213,9 @@ public final class Field {
         FIELD_MAP.put("processed", new ExtendedFieldURI(0x65e8, ExtendedFieldURI.PropertyType.Boolean));
 
         FIELD_MAP.put("reminderset", new UnindexedFieldURI("item:ReminderIsSet"));
-        FIELD_MAP.put("ismeeting", new UnindexedFieldURI("item:IsMeeting"));
+        FIELD_MAP.put("reminderminutesbeforestart", new UnindexedFieldURI("item:ReminderMinutesBeforeStart"));
+
+        FIELD_MAP.put("ismeeting", new UnindexedFieldURI("calendar:IsMeeting"));
         FIELD_MAP.put("apptstateflags", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.Appointment, 0x8217, ExtendedFieldURI.PropertyType.Integer)); // PidLidAppointmentStateFlags 1: Meeting, 2: Received, 4: Cancelled
         FIELD_MAP.put("appointmentstate", new UnindexedFieldURI("calendar:AppointmentState"));
         FIELD_MAP.put("myresponsetype", new UnindexedFieldURI("calendar:MyResponseType"));
@@ -216,11 +223,18 @@ public final class Field {
 
         FIELD_MAP.put("meetingtimezone", new UnindexedFieldURI("calendar:MeetingTimeZone"));
         FIELD_MAP.put("starttimezone", new UnindexedFieldURI("calendar:StartTimeZone"));
+        FIELD_MAP.put("endtimezone", new UnindexedFieldURI("calendar:EndTimeZone"));
         FIELD_MAP.put("busystatus", new UnindexedFieldURI("calendar:LegacyFreeBusyStatus"));
 
         FIELD_MAP.put("requiredattendees", new UnindexedFieldURI("calendar:RequiredAttendees"));
         FIELD_MAP.put("optionalattendees", new UnindexedFieldURI("calendar:OptionalAttendees"));
         FIELD_MAP.put("modifiedoccurrences", new UnindexedFieldURI("calendar:ModifiedOccurrences"));
+        FIELD_MAP.put("deletedoccurrences", new UnindexedFieldURI("calendar:DeletedOccurrences"));
+
+        FIELD_MAP.put("recurrence", new UnindexedFieldURI("calendar:Recurrence"));
+
+        FIELD_MAP.put("isalldayevent", new UnindexedFieldURI("calendar:IsAllDayEvent"));
+        FIELD_MAP.put("myresponsetype", new UnindexedFieldURI("calendar:MyResponseType"));
 
         // does not work with Office 365, see https://msdn.microsoft.com/en-us/library/office/bb204271(v=exchg.150).aspx
         //FIELD_MAP.put("isrecurring", new UnindexedFieldURI("calendar:IsRecurring"));
@@ -232,6 +246,8 @@ public final class Field {
         FIELD_MAP.put("recurrencestart", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.Appointment, 0x8235, ExtendedFieldURI.PropertyType.SystemTime));
         FIELD_MAP.put("recurrencetype", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.Appointment, 0x8231, ExtendedFieldURI.PropertyType.Integer));
 
+        FIELD_MAP.put("location", new UnindexedFieldURI("calendar:Location"));
+
         FIELD_MAP.put("xmozlastack", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.PublicStrings, "xmozlastack"));
         FIELD_MAP.put("xmozsnoozetime", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.PublicStrings, "xmozsnoozetime"));
         FIELD_MAP.put("xmozsendinvitations", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.PublicStrings, "xmozsendinvitations"));
