@@ -224,10 +224,12 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
                         trayItem = new TrayItem(tray, SWT.NONE);
                         trayItem.setToolTipText(BundleMessage.format("UI_DAVMAIL_GATEWAY"));
 
-                        // check if tray is indeed available
-                        if (systemLookAndFeelClassName.contains("gtk")) {
+                        // Under Unity, check if tray is indeed available
+                        if (systemLookAndFeelClassName.contains("gtk") &&
+                                "Unity".equals(System.getenv("XDG_CURRENT_DESKTOP"))) {
                             GdkRectangle area = new GdkRectangle();
                             OS.gtk_status_icon_get_geometry(trayItem.handle, 0, area, 0);
+
                             if (area.x == 0 && area.y == 0) {
                                 throw new Error("System tray not available");
                             }
