@@ -91,6 +91,9 @@ public class TestImap extends AbstractImapTestCase {
     }
 
     public void testUidStoreDeletedFlag() throws IOException {
+        // restore standard IMAP behaviour
+        Settings.setProperty("davmail.imapAutoExpunge", "false");
+
         resetTestFolder();
         appendMessage();
 
@@ -214,7 +217,7 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK UID FETCH completed", readFullAnswer("."));
 
         // check server side categories
-        ExchangeSession session = ExchangeSessionFactory.getInstance(Settings.getProperty("davmail.username"),Settings.getProperty("davmail.password"));
+        ExchangeSession session = ExchangeSessionFactory.getInstance(username,password);
         ExchangeSession.Folder folder = session.getFolder("testfolder");
         folder.loadMessages();
         assertEquals("To Do", folder.get(0).keywords);
@@ -239,7 +242,7 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK UID FETCH completed", readFullAnswer("."));
 
         // check server side categories
-        ExchangeSession session = ExchangeSessionFactory.getInstance(Settings.getProperty("davmail.username"),Settings.getProperty("davmail.password"));
+        ExchangeSession session = ExchangeSessionFactory.getInstance(username, password);
         ExchangeSession.Folder folder = session.getFolder("testfolder");
         folder.loadMessages();
         assertEquals("Some Category", folder.get(0).keywords);
@@ -368,6 +371,15 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK UID FETCH completed", readFullAnswer("."));
     }
 
+    public void testIcedoveHeaderFetch() throws IOException {
+        resetTestFolder();
+        appendMessage();
+
+        writeLine(". UID FETCH 1:* (RFC822.SIZE RFC822.HEADER FLAGS)");
+        assertEquals(". OK UID FETCH completed", readFullAnswer("."));
+    }
+
+
     public void testSearchHeader() throws IOException {
         resetTestFolder();
         appendMessage();
@@ -396,6 +408,14 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK SEARCH completed", readFullAnswer("."));
     }
 
+    public void testMultipleConditionSearch() throws IOException {
+        resetTestFolder();
+        appendMessage();
+
+        writeLine(". UID SEARCH NOT (ANSWERED) NOT (DELETED) NOT (SEEN) NOT (KEYWORD spring-integration-mail-adapter) ALL");
+        assertEquals(". OK SEARCH completed", readFullAnswer("."));
+    }
+
     public void testSearchCharset() throws IOException {
         resetTestFolder();
         appendMessage();
@@ -420,6 +440,14 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK SEARCH completed", readFullAnswer("."));
     }
 
+    public void testSearchSinceOn() throws IOException {
+        resetTestFolder();
+        appendMessage();
+
+        writeLine(". UID SEARCH OR SINCE 1-Jan-2012 ON 1-Jan-2012 ALL");
+        assertEquals(". OK SEARCH completed", readFullAnswer("."));
+    }
+
     public void testSearchText() throws IOException {
         resetTestFolder();
         appendMessage();
